#!/usr/bin/env python

# Inspire by Conbagui tutorial found here: http://fav.me/ddit8ur
# author: Pocholo
# date: 6/6/20

# Comments directed to http://gimpchat.com

# Installation:
# This script should be placed in the user plugin folder

# Copyright (C)

#   This program is free software: you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by   
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.

#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program.  If not, see <https://www.gnu.org/licenses/>.


from gimpfu import *

def pm_icon_pressed_effect(size, foreColor, backColor, pressedColor):
		
	#Initiates the temporary state
	pdb.gimp_context_push()
	
	#Variables
	x = size/550
	
	#Create a new image
	img = pdb.gimp_image_new(size, size, RGB)
		
	#Create a transparent background
	backLayer = pdb.gimp_layer_new(img, size, size, RGB_IMAGE, "Background", 100, LAYER_MODE_NORMAL)
	pdb.gimp_image_add_layer(img, backLayer, 0)
	pdb.gimp_layer_add_alpha(backLayer)
	pdb.gimp_drawable_fill(backLayer, FILL_TRANSPARENT)
	
	gimp.Display(img)
	
	#Create the icon background
	pdb.gimp_image_select_round_rectangle(img, 2, 19*x, 19*x, 512*x, 512*x, 50*x, 50*x)
	pdb.gimp_context_set_background(backColor)
	pdb.gimp_edit_bucket_fill(backLayer, BUCKET_FILL_BG, LAYER_MODE_NORMAL, 100, 255, FALSE, 0, 0)		
	pdb.gimp_context_set_foreground(foreColor)
	pdb.gimp_edit_blend(backLayer, 2, LAYER_MODE_NORMAL, 0, 100, 0, 0, FALSE, TRUE, 5, 0.20, TRUE, 275*x, 20*x, 275*x, 275*x)

	#Bevel and Emboss	
	pdb.python_layerfx_bevel_emboss(img, backLayer, 
									         1,   #style inner bevel
								            65,   #depth 
								             0,   #direction 
								             7,   #size 
									         4,   #soften
								            90,   #angle 
								            30,   #altitude 
									         0,   #gloss_contour - linear
							   (255, 255, 255),   #highlight_color 
								             4,   #highlight_mode-screen
								            75,   #highlight_opacity
							       (78, 48, 0),   #shadow_color 
								             3,   #shadow_mode-multiply
								            60,   #shadow_opacity 
								             0,   #surface_contour - linear 
								         FALSE,   #use_texture 
							       "Dried mud",   #pattern 
								           100,   #scale 
								           100,   #tex_depth 
								          TRUE,   #invert 
								         FALSE)   #merge
										 
	#Inner Glow								   
	pdb.python_layerfx_inner_glow(img, backLayer, 
							       (0, 0, 0),   #color
									      75,   #opacity
										   0,   #contou - linear
										   0,   #noise
						                   3,   #mode - multiply 
										   1,   #source
										   0,   #choke 
									      10,   #size 
									   FALSE)   #merge
											 
	
	#Create a copy 
	non_empty = pdb.gimp_edit_copy(backLayer)
	copyLayer = pdb.gimp_layer_new(img, size, size, RGB, "Copy", 100, LAYER_MODE_NORMAL)
	pdb.gimp_image_add_layer(img, copyLayer, 0)
	pdb.gimp_layer_add_alpha(copyLayer)
	pdb.gimp_drawable_fill(copyLayer, FILL_TRANSPARENT)
	floating_sel = pdb.gimp_edit_paste(copyLayer, FALSE)
	pdb.gimp_floating_sel_anchor(floating_sel)
	
	#Gaussian blur and merge
	pdb.gimp_image_select_item(img, 2, copyLayer)
	pdb.plug_in_gauss_rle2(img, copyLayer, 120, 120)
	backLayer = pdb.gimp_image_merge_visible_layers(img, 2)
	pdb.gimp_selection_none(img)
		
	#Create icon layer
	iconLayer = pdb.gimp_layer_new(img, size, size, RGB, "Icon", 100, LAYER_MODE_NORMAL)
	pdb.gimp_image_add_layer(img, iconLayer, 0)
	pdb.gimp_layer_add_alpha(iconLayer)
	pdb.gimp_drawable_fill(iconLayer, FILL_TRANSPARENT)
		
	#Paint icon
	name = pdb.gimp_context_get_brush()
	pdb.gimp_context_set_brush_size(500*x)
	pdb.gimp_context_set_foreground (pressedColor)
	pdb.gimp_paintbrush_default(iconLayer, 2, [275*x, 275*x])
		
	#Drop Shadow
	pdb.python_layerfx_drop_shadow(img, iconLayer, 
								  (190, 125, 207),   #color
											   75,   #opacity
												0,   #contou - linear
												0,   #noise 
												5,   #mode - overlay
												0,   #spread 
											    1,   #size 
											  100,   #offset_angle 
												2,   #offset_distance 
											 TRUE,   #knockout 
											FALSE)   #merge
	
	
	#Text inner shadow
	pdb.python_layerfx_inner_shadow(img, iconLayer, 
									 (0, 0, 0),   #color
									        75,   #opacity
										     0,   #contou -linear
										     0,   #noise
										     3,   #mode - multiply
										     1,   #source
										     0,   #choke 
									         6,   #size 
										   100,   #offset_angle 
										     8,   #offset_distance 
									      FALSE)  #merge
	
	
	#Inner Glow								   
	pdb.python_layerfx_inner_glow(img, iconLayer, 
							       (0, 0, 0),   #color
									      30,   #opacity
										   0,   #contou - linear
										   0,   #noise
						                   3,   #mode - multiply 
										   1,   #source
										   0,   #choke 
									       3,   #size 
									   FALSE)   #merge
		
	#Resets the previous user defaults
	pdb.gimp_context_pop()
		
	
	
register(
	"pm_icon_pressed_effect",
	"Creates a pressed icon",
	"Creates a pressed icon",
	"Pocholo",
	"Pocholo",
	"2020",
	"Icon pressed effect",
	"",
[
	
	(PF_ADJUSTMENT, "size", "Icon size", 550, (200, 1000, 1)),
	(PF_COLOR, "foreColor", "Foreground color", (200, 85, 255)),
	(PF_COLOR, "backColor", "Background color", (150, 84, 180)),
	(PF_COLOR, "pressedColor", "Pressed color", (71, 30, 85)),	
],
[],
pm_icon_pressed_effect, menu="<Image>/Pocholo-scripts/Icon pressed effect"),
main()		